/* Generated by re2c 1.3 on Wed May  4 13:19:39 2022 */
#line 1 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
// {{{ MIT License

// Copyright 2017 Roland Kaminski

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

// }}}

#define YYCTYPE     char
#define YYCURSOR    cursor()
#define YYLIMIT     limit()
#define YYMARKER    marker()
#define YYFILL(n)   {fill(n);}
#define YYCTXMARKER ctxmarker()
#define YYGETCONDITION condition
#define YYSETCONDITION condition

// Note: THEORYOP is also used in output/backends.cc
#line 57 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"


int Gringo::Input::NonGroundParser::lex_impl(void *pValue, Location &loc) {
    int bc = 0;
    auto &value = *static_cast<Gringo::Input::NonGroundGrammar::parser::semantic_type*>(pValue);
    start(loc);
    for (;;) {
        
#line 47 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
{
	YYCTYPE yych;
	unsigned int yyaccept = 0;
	switch (YYGETCONDITION()) {
	case yycdefinition: goto yyc_definition;
	case yycnormal: goto yyc_normal;
	case yycscript: goto yyc_script;
	case yyctheory: goto yyc_theory;
	case yycscript_body: goto yyc_script_body;
	case yycblockcomment: goto yyc_blockcomment;
	case yyccomment: goto yyc_comment;
	}
/* *********************************** */
yyc_definition:
	if ((YYLIMIT - YYCURSOR) < 10) YYFILL(10);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy5;
	case '\n':	goto yy8;
	case '#':	goto yy10;
	case '%':	goto yy12;
	case '&':	goto yy14;
	case '\'':
	case '_':	goto yy16;
	case ',':	goto yy17;
	case '.':	goto yy19;
	case '/':	goto yy21;
	case '0':	goto yy23;
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy25;
	case ':':	goto yy27;
	case ';':	goto yy29;
	case 'a':	goto yy31;
	case 'b':	goto yy33;
	case 'c':
	case 'e':
	case 'f':
	case 'g':
	case 'i':
	case 'j':
	case 'k':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 's':
	case 't':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	case 'd':	goto yy36;
	case 'h':	goto yy37;
	case 'l':	goto yy38;
	case 'r':	goto yy39;
	case 'u':	goto yy40;
	case '{':	goto yy41;
	case '}':	goto yy43;
	default:	goto yy3;
	}
yy3:
	++YYCURSOR;
yy4:
#line 160 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ lexerError(end(loc), string()); continue; }
#line 124 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy5:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy5;
	default:	goto yy7;
	}
yy7:
#line 65 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ start(loc); continue; }
#line 138 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy8:
	++YYCURSOR;
#line 66 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ if(eof()) return 0; step(); start(loc); continue; }
#line 143 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy10:
	yych = *++YYCURSOR;
	switch (yych) {
	case '!':	goto yy45;
	default:	goto yy48;
	}
yy11:
#line 159 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ lexerError(end(loc), string()); continue; }
#line 153 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy12:
	yych = *++YYCURSOR;
	switch (yych) {
	case '*':	goto yy49;
	default:	goto yy13;
	}
yy13:
	YYSETCONDITION(yyccomment);
	continue;
yy14:
	++YYCURSOR;
#line 139 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::AND; }
#line 167 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy16:
	yyaccept = 0;
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case '\'':
	case '_':	goto yy51;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	default:	goto yy4;
	}
yy17:
	++YYCURSOR;
#line 115 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::COMMA; }
#line 206 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy19:
	++YYCURSOR;
#line 111 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::DOT; }
#line 211 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy21:
	++YYCURSOR;
#line 137 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SLASH; }
#line 216 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy23:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case 'b':	goto yy54;
	case 'o':	goto yy55;
	case 'x':	goto yy56;
	default:	goto yy24;
	}
yy24:
#line 96 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.num = integer(); return NonGroundGrammar::parser::token::NUMBER; }
#line 229 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy25:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy25;
	default:	goto yy24;
	}
yy27:
	++YYCURSOR;
#line 112 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::COLON; }
#line 251 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy29:
	++YYCURSOR;
#line 109 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SEM; }
#line 256 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy31:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy57;
	default:	goto yy35;
	}
yy32:
#line 95 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(string()); return NonGroundGrammar::parser::token::IDENTIFIER; }
#line 266 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy33:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy58;
	case 'o':	goto yy59;
	default:	goto yy35;
	}
yy34:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy35:
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	default:	goto yy32;
	}
yy36:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy60;
	default:	goto yy35;
	}
yy37:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy61;
	default:	goto yy35;
	}
yy38:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy62;
	default:	goto yy35;
	}
yy39:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy63;
	default:	goto yy35;
	}
yy40:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy64;
	default:	goto yy35;
	}
yy41:
	++YYCURSOR;
#line 122 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::LBRACE; }
#line 380 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy43:
	++YYCURSOR;
#line 123 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::RBRACE; }
#line 385 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy45:
	++YYCURSOR;
	YYSETCONDITION(yyccomment);
	continue;
yy47:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy48:
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy47;
	default:	goto yy11;
	}
yy49:
	++YYCURSOR;
	YYSETCONDITION(yycblockcomment);
#line 156 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ bc++; continue; }
#line 466 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy51:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\'':
	case '_':	goto yy51;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	default:	goto yy53;
	}
yy53:
	YYCURSOR = YYMARKER;
	if (yyaccept == 0) {
		goto yy4;
	} else {
		goto yy24;
	}
yy54:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':	goto yy65;
	default:	goto yy53;
	}
yy55:
	yych = *++YYCURSOR;
	switch (yych) {
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy67;
	default:	goto yy53;
	}
yy56:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':	goto yy69;
	default:	goto yy53;
	}
yy57:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'y':	goto yy71;
	default:	goto yy35;
	}
yy58:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy73;
	default:	goto yy35;
	}
yy59:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'd':	goto yy74;
	default:	goto yy35;
	}
yy60:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'r':	goto yy75;
	default:	goto yy35;
	}
yy61:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'a':	goto yy76;
	default:	goto yy35;
	}
yy62:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'f':	goto yy77;
	default:	goto yy35;
	}
yy63:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'g':	goto yy78;
	default:	goto yy35;
	}
yy64:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'a':	goto yy79;
	default:	goto yy35;
	}
yy65:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '0':
	case '1':	goto yy65;
	default:	goto yy24;
	}
yy67:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy67;
	default:	goto yy24;
	}
yy69:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':	goto yy69;
	default:	goto yy24;
	}
yy71:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	default:	goto yy72;
	}
yy72:
#line 86 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::ANY; }
#line 727 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy73:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'a':	goto yy80;
	default:	goto yy35;
	}
yy74:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'y':	goto yy81;
	default:	goto yy35;
	}
yy75:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy83;
	default:	goto yy35;
	}
yy76:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'd':	goto yy84;
	default:	goto yy35;
	}
yy77:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy86;
	default:	goto yy35;
	}
yy78:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'h':	goto yy88;
	default:	goto yy35;
	}
yy79:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'r':	goto yy89;
	default:	goto yy35;
	}
yy80:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'r':	goto yy90;
	default:	goto yy35;
	}
yy81:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	default:	goto yy82;
	}
yy82:
#line 85 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::BODY; }
#line 848 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy83:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'c':	goto yy91;
	default:	goto yy35;
	}
yy84:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	default:	goto yy85;
	}
yy85:
#line 84 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::HEAD; }
#line 927 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy86:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	default:	goto yy87;
	}
yy87:
#line 82 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::LEFT; }
#line 1000 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy88:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy92;
	default:	goto yy35;
	}
yy89:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'y':	goto yy94;
	default:	goto yy35;
	}
yy90:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'y':	goto yy96;
	default:	goto yy35;
	}
yy91:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy98;
	default:	goto yy35;
	}
yy92:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	default:	goto yy93;
	}
yy93:
#line 83 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::RIGHT; }
#line 1097 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy94:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	default:	goto yy95;
	}
yy95:
#line 88 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::UNARY; }
#line 1170 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy96:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	default:	goto yy97;
	}
yy97:
#line 87 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::BINARY; }
#line 1243 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy98:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy99;
	default:	goto yy35;
	}
yy99:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'v':	goto yy100;
	default:	goto yy35;
	}
yy100:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy101;
	default:	goto yy35;
	}
yy101:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy34;
	default:	goto yy102;
	}
yy102:
#line 89 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::DIRECTIVE; }
#line 1334 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
/* *********************************** */
yyc_normal:
	if ((YYLIMIT - YYCURSOR) < 11) YYFILL(11);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy107;
	case '\n':	goto yy110;
	case '!':	goto yy112;
	case '"':	goto yy113;
	case '#':	goto yy114;
	case '$':	goto yy116;
	case '%':	goto yy118;
	case '&':	goto yy120;
	case '\'':	goto yy122;
	case '(':	goto yy123;
	case ')':	goto yy125;
	case '*':	goto yy127;
	case '+':	goto yy129;
	case ',':	goto yy131;
	case '-':	goto yy133;
	case '.':	goto yy135;
	case '/':	goto yy137;
	case '0':	goto yy139;
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy141;
	case ':':	goto yy143;
	case ';':	goto yy145;
	case '<':	goto yy147;
	case '=':	goto yy149;
	case '>':	goto yy151;
	case '?':	goto yy153;
	case '@':	goto yy155;
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':	goto yy157;
	case '[':	goto yy160;
	case '\\':	goto yy162;
	case ']':	goto yy164;
	case '^':	goto yy166;
	case '_':	goto yy168;
	case 'a':
	case 'b':
	case 'c':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy170;
	case 'd':	goto yy173;
	case 'n':	goto yy174;
	case 'o':	goto yy175;
	case '{':	goto yy176;
	case '|':	goto yy178;
	case '}':	goto yy180;
	case '~':	goto yy182;
	default:	goto yy105;
	}
yy105:
	++YYCURSOR;
yy106:
#line 160 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ lexerError(end(loc), string()); continue; }
#line 1444 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy107:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy107;
	default:	goto yy109;
	}
yy109:
#line 65 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ start(loc); continue; }
#line 1458 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy110:
	++YYCURSOR;
#line 66 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ if(eof()) return 0; step(); start(loc); continue; }
#line 1463 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy112:
	yych = *++YYCURSOR;
	switch (yych) {
	case '=':	goto yy184;
	default:	goto yy106;
	}
yy113:
	yyaccept = 0;
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case '\n':	goto yy106;
	default:	goto yy187;
	}
yy114:
	yych = *++YYCURSOR;
	switch (yych) {
	case '!':	goto yy192;
	case 'c':	goto yy196;
	case 'd':	goto yy197;
	case 'e':	goto yy198;
	case 'f':	goto yy199;
	case 'h':	goto yy200;
	case 'i':	goto yy201;
	case 'm':	goto yy202;
	case 'p':	goto yy203;
	case 's':	goto yy204;
	case 't':	goto yy205;
	default:	goto yy195;
	}
yy115:
#line 159 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ lexerError(end(loc), string()); continue; }
#line 1496 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy116:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case '!':	goto yy206;
	case '*':	goto yy207;
	case '+':	goto yy209;
	case '-':	goto yy211;
	case '<':	goto yy213;
	case '=':	goto yy215;
	case '>':	goto yy217;
	default:	goto yy117;
	}
yy117:
#line 143 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP; }
#line 1513 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy118:
	yych = *++YYCURSOR;
	switch (yych) {
	case '*':	goto yy219;
	default:	goto yy119;
	}
yy119:
	YYSETCONDITION(yyccomment);
	continue;
yy120:
	++YYCURSOR;
#line 139 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::AND; }
#line 1527 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy122:
	yyaccept = 0;
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case '\'':
	case '_':	goto yy221;
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':	goto yy157;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy170;
	default:	goto yy106;
	}
yy123:
	++YYCURSOR;
#line 119 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::LPAREN; }
#line 1592 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy125:
	++YYCURSOR;
#line 120 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::RPAREN; }
#line 1597 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy127:
	yych = *++YYCURSOR;
	switch (yych) {
	case '*':	goto yy223;
	default:	goto yy128;
	}
yy128:
#line 128 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::MUL; }
#line 1607 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy129:
	++YYCURSOR;
#line 124 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::ADD; }
#line 1612 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy131:
	++YYCURSOR;
#line 115 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::COMMA; }
#line 1617 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy133:
	++YYCURSOR;
#line 125 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SUB; }
#line 1622 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy135:
	yych = *++YYCURSOR;
	switch (yych) {
	case '.':	goto yy225;
	default:	goto yy136;
	}
yy136:
#line 111 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::DOT; }
#line 1632 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy137:
	++YYCURSOR;
#line 137 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SLASH; }
#line 1637 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy139:
	yyaccept = 2;
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case 'b':	goto yy227;
	case 'o':	goto yy228;
	case 'x':	goto yy229;
	default:	goto yy140;
	}
yy140:
#line 96 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.num = integer(); return NonGroundGrammar::parser::token::NUMBER; }
#line 1650 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy141:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy141;
	default:	goto yy140;
	}
yy143:
	yych = *++YYCURSOR;
	switch (yych) {
	case '-':	goto yy230;
	case '~':	goto yy232;
	default:	goto yy144;
	}
yy144:
#line 112 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::COLON; }
#line 1678 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy145:
	++YYCURSOR;
#line 109 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SEM; }
#line 1683 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy147:
	yych = *++YYCURSOR;
	switch (yych) {
	case '=':	goto yy234;
	case '>':	goto yy236;
	default:	goto yy148;
	}
yy148:
#line 130 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::LT; }
#line 1694 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy149:
	yych = *++YYCURSOR;
	switch (yych) {
	case '=':	goto yy238;
	default:	goto yy150;
	}
yy150:
#line 136 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::EQ; }
#line 1704 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy151:
	yych = *++YYCURSOR;
	switch (yych) {
	case '=':	goto yy240;
	default:	goto yy152;
	}
yy152:
#line 129 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::GT; }
#line 1714 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy153:
	++YYCURSOR;
#line 142 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::QUESTION; }
#line 1719 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy155:
	++YYCURSOR;
#line 138 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::AT; }
#line 1724 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy157:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy157;
	default:	goto yy159;
	}
yy159:
#line 97 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(string()); return NonGroundGrammar::parser::token::VARIABLE; }
#line 1799 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy160:
	++YYCURSOR;
#line 117 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::LBRACK; }
#line 1804 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy162:
	++YYCURSOR;
#line 127 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::MOD; }
#line 1809 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy164:
	++YYCURSOR;
#line 118 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::RBRACK; }
#line 1814 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy166:
	++YYCURSOR;
#line 140 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::XOR; }
#line 1819 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy168:
	yyaccept = 3;
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case '\'':
	case '_':	goto yy221;
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':	goto yy157;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy170;
	default:	goto yy169;
	}
yy169:
#line 94 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::ANONYMOUS; }
#line 1883 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy170:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy171:
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy170;
	default:	goto yy172;
	}
yy172:
#line 95 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(string()); return NonGroundGrammar::parser::token::IDENTIFIER; }
#line 1959 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy173:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy242;
	default:	goto yy171;
	}
yy174:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'o':	goto yy243;
	default:	goto yy171;
	}
yy175:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'v':	goto yy244;
	default:	goto yy171;
	}
yy176:
	++YYCURSOR;
#line 122 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::LBRACE; }
#line 1982 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy178:
	++YYCURSOR;
#line 116 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::VBAR; }
#line 1987 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy180:
	++YYCURSOR;
#line 123 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::RBRACE; }
#line 1992 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy182:
	++YYCURSOR;
#line 141 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::BNOT; }
#line 1997 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy184:
	++YYCURSOR;
#line 134 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::NEQ; }
#line 2002 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy186:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy187:
	switch (yych) {
	case '\n':	goto yy188;
	case '"':	goto yy189;
	case '\\':	goto yy191;
	default:	goto yy186;
	}
yy188:
	YYCURSOR = YYMARKER;
	switch (yyaccept) {
	case 0: 	goto yy106;
	case 1: 	goto yy117;
	case 2: 	goto yy140;
	case 3: 	goto yy169;
	case 4: 	goto yy324;
	default:	goto yy115;
	}
yy189:
	++YYCURSOR;
#line 98 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(unquote(string(1, 1)).c_str()); return NonGroundGrammar::parser::token::STRING; }
#line 2028 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy191:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '"':
	case '\\':
	case 'n':	goto yy186;
	default:	goto yy188;
	}
yy192:
	++YYCURSOR;
	YYSETCONDITION(yyccomment);
	continue;
yy194:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy195:
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy115;
	}
yy196:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'o':	goto yy245;
	default:	goto yy195;
	}
yy197:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy246;
	case 'i':	goto yy247;
	default:	goto yy195;
	}
yy198:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'd':	goto yy248;
	case 'x':	goto yy249;
	default:	goto yy195;
	}
yy199:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'a':	goto yy250;
	default:	goto yy195;
	}
yy200:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy251;
	default:	goto yy195;
	}
yy201:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy252;
	default:	goto yy195;
	}
yy202:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'a':	goto yy253;
	case 'i':	goto yy254;
	default:	goto yy195;
	}
yy203:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'r':	goto yy255;
	default:	goto yy195;
	}
yy204:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'c':	goto yy256;
	case 'h':	goto yy257;
	case 'u':	goto yy258;
	default:	goto yy195;
	}
yy205:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'h':	goto yy259;
	case 'r':	goto yy260;
	default:	goto yy195;
	}
yy206:
	yych = *++YYCURSOR;
	switch (yych) {
	case '=':	goto yy261;
	default:	goto yy188;
	}
yy207:
	++YYCURSOR;
#line 146 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP_MUL; }
#line 2190 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy209:
	++YYCURSOR;
#line 144 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP_ADD; }
#line 2195 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy211:
	++YYCURSOR;
#line 145 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP_SUB; }
#line 2200 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy213:
	yych = *++YYCURSOR;
	switch (yych) {
	case '=':	goto yy263;
	case '>':	goto yy265;
	default:	goto yy214;
	}
yy214:
#line 148 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP_LT; }
#line 2211 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy215:
	yych = *++YYCURSOR;
	switch (yych) {
	case '=':	goto yy267;
	default:	goto yy216;
	}
yy216:
#line 152 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP_EQ; }
#line 2221 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy217:
	yych = *++YYCURSOR;
	switch (yych) {
	case '=':	goto yy269;
	default:	goto yy218;
	}
yy218:
#line 150 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP_GT; }
#line 2231 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy219:
	++YYCURSOR;
	YYSETCONDITION(yycblockcomment);
#line 156 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ bc++; continue; }
#line 2237 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy221:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\'':
	case '_':	goto yy221;
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':	goto yy157;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy170;
	default:	goto yy188;
	}
yy223:
	++YYCURSOR;
#line 126 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::POW; }
#line 2303 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy225:
	++YYCURSOR;
#line 110 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::DOTS; }
#line 2308 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy227:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':	goto yy271;
	default:	goto yy188;
	}
yy228:
	yych = *++YYCURSOR;
	switch (yych) {
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy273;
	default:	goto yy188;
	}
yy229:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':	goto yy275;
	default:	goto yy188;
	}
yy230:
	++YYCURSOR;
#line 113 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::IF; }
#line 2359 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy232:
	++YYCURSOR;
#line 114 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::WIF; }
#line 2364 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy234:
	++YYCURSOR;
#line 132 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::LEQ; }
#line 2369 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy236:
	++YYCURSOR;
#line 135 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::NEQ; }
#line 2374 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy238:
	++YYCURSOR;
#line 133 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::EQ; }
#line 2379 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy240:
	++YYCURSOR;
#line 131 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::GEQ; }
#line 2384 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy242:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'f':	goto yy277;
	default:	goto yy171;
	}
yy243:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy278;
	default:	goto yy171;
	}
yy244:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy280;
	default:	goto yy171;
	}
yy245:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy281;
	case 'u':	goto yy282;
	default:	goto yy195;
	}
yy246:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'f':	goto yy283;
	default:	goto yy195;
	}
yy247:
	yych = *++YYCURSOR;
	switch (yych) {
	case 's':	goto yy284;
	default:	goto yy195;
	}
yy248:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'g':	goto yy285;
	default:	goto yy195;
	}
yy249:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy286;
	default:	goto yy195;
	}
yy250:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'l':	goto yy287;
	default:	goto yy195;
	}
yy251:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'u':	goto yy288;
	default:	goto yy195;
	}
yy252:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'c':	goto yy289;
	case 'f':	goto yy290;
	default:	goto yy195;
	}
yy253:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'x':	goto yy292;
	default:	goto yy195;
	}
yy254:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy294;
	default:	goto yy195;
	}
yy255:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'o':	goto yy296;
	default:	goto yy195;
	}
yy256:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'r':	goto yy297;
	default:	goto yy195;
	}
yy257:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'o':	goto yy298;
	default:	goto yy195;
	}
yy258:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy299;
	case 'p':	goto yy301;
	default:	goto yy195;
	}
yy259:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy303;
	default:	goto yy195;
	}
yy260:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'u':	goto yy304;
	default:	goto yy195;
	}
yy261:
	++YYCURSOR;
#line 153 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP_NEQ; }
#line 2506 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy263:
	++YYCURSOR;
#line 147 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP_LEQ; }
#line 2511 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy265:
	++YYCURSOR;
#line 154 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP_NEQ; }
#line 2516 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy267:
	++YYCURSOR;
#line 151 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP_EQ; }
#line 2521 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy269:
	++YYCURSOR;
#line 149 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CSP_GEQ; }
#line 2526 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy271:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '0':
	case '1':	goto yy271;
	default:	goto yy140;
	}
yy273:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy273;
	default:	goto yy140;
	}
yy275:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':	goto yy275;
	default:	goto yy140;
	}
yy277:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'a':	goto yy305;
	default:	goto yy171;
	}
yy278:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy170;
	default:	goto yy279;
	}
yy279:
#line 91 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(not_); return NonGroundGrammar::parser::token::NOT; }
#line 2657 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy280:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'r':	goto yy306;
	default:	goto yy171;
	}
yy281:
	yych = *++YYCURSOR;
	switch (yych) {
	case 's':	goto yy307;
	default:	goto yy195;
	}
yy282:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy308;
	default:	goto yy195;
	}
yy283:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy309;
	default:	goto yy195;
	}
yy284:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'j':	goto yy310;
	default:	goto yy195;
	}
yy285:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy311;
	default:	goto yy195;
	}
yy286:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy313;
	default:	goto yy195;
	}
yy287:
	yych = *++YYCURSOR;
	switch (yych) {
	case 's':	goto yy314;
	default:	goto yy195;
	}
yy288:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'r':	goto yy315;
	default:	goto yy195;
	}
yy289:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'l':	goto yy316;
	default:	goto yy195;
	}
yy290:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	case 'i':	goto yy317;
	default:	goto yy291;
	}
yy291:
#line 67 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::INFIMUM; }
#line 2789 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy292:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	case 'i':	goto yy318;
	default:	goto yy293;
	}
yy293:
#line 106 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::MAX; }
#line 2861 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy294:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	case 'i':	goto yy319;
	default:	goto yy295;
	}
yy295:
#line 105 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::MIN; }
#line 2933 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy296:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'g':	goto yy320;
	case 'j':	goto yy321;
	default:	goto yy195;
	}
yy297:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy322;
	default:	goto yy195;
	}
yy298:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'w':	goto yy323;
	default:	goto yy195;
	}
yy299:
	yych = *++YYCURSOR;
	switch (yych) {
	case '+':	goto yy325;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy300;
	}
yy300:
#line 102 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SUM; }
#line 3025 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy301:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	case 'r':	goto yy327;
	default:	goto yy302;
	}
yy302:
#line 68 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SUPREMUM; }
#line 3097 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy303:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'o':	goto yy328;
	default:	goto yy195;
	}
yy304:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy329;
	default:	goto yy195;
	}
yy305:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'u':	goto yy331;
	default:	goto yy171;
	}
yy306:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'r':	goto yy332;
	default:	goto yy171;
	}
yy307:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy333;
	default:	goto yy195;
	}
yy308:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy335;
	default:	goto yy195;
	}
yy309:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy337;
	default:	goto yy195;
	}
yy310:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'o':	goto yy338;
	default:	goto yy195;
	}
yy311:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy312;
	}
yy312:
#line 71 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::EDGE; }
#line 3217 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy313:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'r':	goto yy339;
	default:	goto yy195;
	}
yy314:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy340;
	default:	goto yy195;
	}
yy315:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy342;
	default:	goto yy195;
	}
yy316:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'u':	goto yy343;
	default:	goto yy195;
	}
yy317:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy344;
	default:	goto yy195;
	}
yy318:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy345;
	default:	goto yy195;
	}
yy319:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy346;
	default:	goto yy195;
	}
yy320:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'r':	goto yy347;
	default:	goto yy195;
	}
yy321:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy348;
	default:	goto yy195;
	}
yy322:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'p':	goto yy349;
	default:	goto yy195;
	}
yy323:
	yyaccept = 4;
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':
		YYCTXMARKER = YYCURSOR;
		goto yy350;
	case '$':
	case '-':
		YYCTXMARKER = YYCURSOR;
		goto yy352;
	case '\'':
		YYCTXMARKER = YYCURSOR;
		goto yy354;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':	goto yy194;
	case '_':
		YYCTXMARKER = YYCURSOR;
		goto yy356;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':
		YYCTXMARKER = YYCURSOR;
		goto yy358;
	default:	goto yy324;
	}
yy324:
#line 74 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SHOW; }
#line 3367 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy325:
	++YYCURSOR;
#line 103 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SUMP; }
#line 3372 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy327:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy360;
	default:	goto yy195;
	}
yy328:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'r':	goto yy361;
	default:	goto yy195;
	}
yy329:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy330;
	}
yy330:
#line 100 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::TRUE; }
#line 3456 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy331:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'l':	goto yy362;
	default:	goto yy171;
	}
yy332:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy363;
	default:	goto yy171;
	}
yy333:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy334;
	}
yy334:
#line 76 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::CONST; }
#line 3540 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy335:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy336;
	}
yy336:
#line 104 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::COUNT; }
#line 3612 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy337:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy364;
	default:	goto yy195;
	}
yy338:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy365;
	default:	goto yy195;
	}
yy339:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy366;
	default:	goto yy195;
	}
yy340:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy341;
	}
yy341:
#line 101 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::FALSE; }
#line 3702 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy342:
	yych = *++YYCURSOR;
	switch (yych) {
	case 's':	goto yy367;
	default:	goto yy195;
	}
yy343:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'd':	goto yy368;
	default:	goto yy195;
	}
yy344:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'u':	goto yy369;
	default:	goto yy195;
	}
yy345:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy370;
	default:	goto yy195;
	}
yy346:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy371;
	default:	goto yy195;
	}
yy347:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'a':	goto yy372;
	default:	goto yy195;
	}
yy348:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'c':	goto yy373;
	default:	goto yy195;
	}
yy349:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy374;
	default:	goto yy195;
	}
yy350:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':	goto yy350;
	case '$':
	case '-':	goto yy352;
	case '\'':
	case '_':	goto yy354;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy376;
	default:	goto yy188;
	}
yy352:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':	goto yy352;
	case '\'':
	case '_':	goto yy354;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy376;
	default:	goto yy188;
	}
yy354:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\'':
	case '_':	goto yy354;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy376;
	default:	goto yy188;
	}
yy356:
	yyaccept = 5;
	YYMARKER = ++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\'':	goto yy354;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':	goto yy194;
	case '_':	goto yy356;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy358;
	default:	goto yy115;
	}
yy358:
	yyaccept = 5;
	YYMARKER = ++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':	goto yy378;
	case '\'':	goto yy376;
	case '/':	goto yy380;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy358;
	default:	goto yy115;
	}
yy360:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy382;
	default:	goto yy195;
	}
yy361:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'y':	goto yy383;
	default:	goto yy195;
	}
yy362:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy385;
	default:	goto yy171;
	}
yy363:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'd':	goto yy387;
	default:	goto yy171;
	}
yy364:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'd':	goto yy388;
	default:	goto yy195;
	}
yy365:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy390;
	default:	goto yy195;
	}
yy366:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'a':	goto yy391;
	default:	goto yy195;
	}
yy367:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy392;
	default:	goto yy195;
	}
yy368:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy393;
	default:	goto yy195;
	}
yy369:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy395;
	default:	goto yy195;
	}
yy370:
	yych = *++YYCURSOR;
	switch (yych) {
	case 's':
	case 'z':	goto yy396;
	default:	goto yy195;
	}
yy371:
	yych = *++YYCURSOR;
	switch (yych) {
	case 's':
	case 'z':	goto yy397;
	default:	goto yy195;
	}
yy372:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy398;
	default:	goto yy195;
	}
yy373:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy400;
	default:	goto yy195;
	}
yy374:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy375;
	}
yy375:
	YYSETCONDITION(yycscript);
#line 69 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SCRIPT; }
#line 4173 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy376:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':	goto yy378;
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy376;
	case '/':	goto yy380;
	default:	goto yy188;
	}
yy378:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':	goto yy378;
	case '/':	goto yy380;
	default:	goto yy188;
	}
yy380:
	++YYCURSOR;
	if ((YYLIMIT - YYCURSOR) < 3) YYFILL(3);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':	goto yy380;
	case '0':	goto yy402;
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy403;
	default:	goto yy188;
	}
yy382:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'u':	goto yy405;
	default:	goto yy195;
	}
yy383:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy384;
	}
yy384:
#line 108 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::THEORY; }
#line 4360 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy385:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy170;
	default:	goto yy386;
	}
yy386:
#line 92 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(string()); return NonGroundGrammar::parser::token::DEFAULT; }
#line 4433 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy387:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy406;
	default:	goto yy171;
	}
yy388:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy389;
	}
yy389:
#line 81 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::DEFINED; }
#line 4511 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy390:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy408;
	default:	goto yy195;
	}
yy391:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'l':	goto yy410;
	default:	goto yy195;
	}
yy392:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'i':	goto yy412;
	default:	goto yy195;
	}
yy393:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy394;
	}
yy394:
#line 70 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::INCLUDE; }
#line 4601 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy395:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy291;
	}
yy396:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy413;
	default:	goto yy195;
	}
yy397:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy415;
	default:	goto yy195;
	}
yy398:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy399;
	}
yy399:
#line 79 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::BLOCK; }
#line 4753 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy400:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy401;
	}
yy401:
#line 73 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::PROJECT; }
#line 4825 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy402:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'b':	goto yy421;
	case 'o':	goto yy422;
	case 'x':	goto yy423;
	default:	goto yy418;
	}
yy403:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':	goto yy417;
	case '.':	goto yy419;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy403;
	default:	goto yy188;
	}
yy405:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy424;
	default:	goto yy195;
	}
yy406:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy170;
	default:	goto yy407;
	}
yy407:
#line 93 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(string()); return NonGroundGrammar::parser::token::OVERRIDE; }
#line 4934 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy408:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy409;
	}
yy409:
#line 107 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::DISJOINT; }
#line 5006 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy410:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy411;
	}
yy411:
#line 80 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::EXTERNAL; }
#line 5078 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy412:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'c':	goto yy425;
	default:	goto yy195;
	}
yy413:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy414;
	}
yy414:
#line 78 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::MAXIMIZE; }
#line 5156 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy415:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy416;
	}
yy416:
#line 77 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::MINIMIZE; }
#line 5228 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy417:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy418:
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':	goto yy417;
	case '.':	goto yy419;
	default:	goto yy188;
	}
yy419:
	++YYCURSOR;
	YYCURSOR = YYCTXMARKER;
#line 75 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SHOWSIG; }
#line 5247 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy421:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':	goto yy427;
	default:	goto yy188;
	}
yy422:
	yych = *++YYCURSOR;
	switch (yych) {
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy429;
	default:	goto yy188;
	}
yy423:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':	goto yy431;
	default:	goto yy188;
	}
yy424:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy302;
	}
yy425:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy194;
	default:	goto yy426;
	}
yy426:
#line 72 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::HEURISTIC; }
#line 5433 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy427:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':	goto yy417;
	case '.':	goto yy419;
	case '0':
	case '1':	goto yy427;
	default:	goto yy188;
	}
yy429:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':	goto yy417;
	case '.':	goto yy419;
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy429;
	default:	goto yy188;
	}
yy431:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\n':
	case '\r':
	case ' ':	goto yy417;
	case '.':	goto yy419;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':	goto yy431;
	default:	goto yy188;
	}
/* *********************************** */
yyc_script:
	if ((YYLIMIT - YYCURSOR) < 2) YYFILL(2);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy437;
	case '\n':	goto yy440;
	case '#':	goto yy442;
	case '%':	goto yy444;
	case '\'':
	case '_':	goto yy446;
	case '(':	goto yy447;
	case ')':	goto yy449;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy452;
	default:	goto yy435;
	}
yy435:
	++YYCURSOR;
yy436:
#line 160 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ lexerError(end(loc), string()); continue; }
#line 5549 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy437:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy437;
	default:	goto yy439;
	}
yy439:
#line 65 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ start(loc); continue; }
#line 5563 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy440:
	++YYCURSOR;
#line 66 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ if(eof()) return 0; step(); start(loc); continue; }
#line 5568 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy442:
	yych = *++YYCURSOR;
	switch (yych) {
	case '!':	goto yy455;
	default:	goto yy458;
	}
yy443:
#line 159 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ lexerError(end(loc), string()); continue; }
#line 5578 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy444:
	yych = *++YYCURSOR;
	switch (yych) {
	case '*':	goto yy459;
	default:	goto yy445;
	}
yy445:
	YYSETCONDITION(yyccomment);
	continue;
yy446:
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case '\'':
	case '_':	goto yy461;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy452;
	default:	goto yy436;
	}
yy447:
	++YYCURSOR;
#line 119 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::LPAREN; }
#line 5625 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy449:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy449;
	default:	goto yy451;
	}
yy451:
	YYSETCONDITION(yycscript_body);
#line 121 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ start(loc); return NonGroundGrammar::parser::token::RPAREN; }
#line 5640 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy452:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy452;
	default:	goto yy454;
	}
yy454:
#line 95 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(string()); return NonGroundGrammar::parser::token::IDENTIFIER; }
#line 5715 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy455:
	++YYCURSOR;
	YYSETCONDITION(yyccomment);
	continue;
yy457:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy458:
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy457;
	default:	goto yy443;
	}
yy459:
	++YYCURSOR;
	YYSETCONDITION(yycblockcomment);
#line 156 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ bc++; continue; }
#line 5796 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy461:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\'':
	case '_':	goto yy461;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy452;
	default:	goto yy463;
	}
yy463:
	YYCURSOR = YYMARKER;
	goto yy436;
/* *********************************** */
yyc_theory:
	if ((YYLIMIT - YYCURSOR) < 10) YYFILL(10);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy468;
	case '\n':	goto yy471;
	case '!':
	case '&':
	case '*':
	case '+':
	case '-':
	case '/':
	case '<':
	case '=':
	case '>':
	case '?':
	case '@':
	case '\\':
	case '^':
	case '|':
	case '~':	goto yy473;
	case '"':	goto yy476;
	case '#':	goto yy477;
	case '%':	goto yy479;
	case '\'':
	case '_':	goto yy481;
	case '(':	goto yy482;
	case ')':	goto yy484;
	case ',':	goto yy486;
	case '.':	goto yy488;
	case '0':	goto yy490;
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy492;
	case ':':	goto yy494;
	case ';':	goto yy496;
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':	goto yy498;
	case '[':	goto yy501;
	case ']':	goto yy503;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy505;
	case 'n':	goto yy508;
	case '{':	goto yy509;
	case '}':	goto yy511;
	default:	goto yy466;
	}
yy466:
	++YYCURSOR;
yy467:
#line 160 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ lexerError(end(loc), string()); continue; }
#line 5943 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy468:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy468;
	default:	goto yy470;
	}
yy470:
#line 65 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ start(loc); continue; }
#line 5957 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy471:
	++YYCURSOR;
#line 66 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ if(eof()) return 0; step(); start(loc); continue; }
#line 5962 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy473:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '!':
	case '&':
	case '*':
	case '+':
	case '-':
	case '.':
	case '/':
	case ':':
	case ';':
	case '<':
	case '=':
	case '>':
	case '?':
	case '@':
	case '\\':
	case '^':
	case '|':
	case '~':	goto yy473;
	default:	goto yy475;
	}
yy475:
#line 155 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(string()); return NonGroundGrammar::parser::token::THEORY_OP; }
#line 5991 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy476:
	yyaccept = 0;
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case '\n':	goto yy467;
	default:	goto yy514;
	}
yy477:
	yych = *++YYCURSOR;
	switch (yych) {
	case '!':	goto yy519;
	case 'i':	goto yy523;
	case 's':	goto yy524;
	default:	goto yy522;
	}
yy478:
#line 159 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ lexerError(end(loc), string()); continue; }
#line 6010 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy479:
	yych = *++YYCURSOR;
	switch (yych) {
	case '*':	goto yy525;
	default:	goto yy480;
	}
yy480:
	YYSETCONDITION(yyccomment);
	continue;
yy481:
	yyaccept = 0;
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case '\'':
	case '_':	goto yy527;
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':	goto yy498;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy505;
	default:	goto yy467;
	}
yy482:
	++YYCURSOR;
#line 119 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::LPAREN; }
#line 6084 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy484:
	++YYCURSOR;
#line 120 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::RPAREN; }
#line 6089 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy486:
	++YYCURSOR;
#line 115 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::COMMA; }
#line 6094 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy488:
	yych = *++YYCURSOR;
	switch (yych) {
	case '!':
	case '&':
	case '*':
	case '+':
	case '-':
	case '.':
	case '/':
	case ':':
	case ';':
	case '<':
	case '=':
	case '>':
	case '?':
	case '@':
	case '\\':
	case '^':
	case '|':
	case '~':	goto yy473;
	default:	goto yy489;
	}
yy489:
#line 111 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::DOT; }
#line 6121 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy490:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case 'b':	goto yy529;
	case 'o':	goto yy530;
	case 'x':	goto yy531;
	default:	goto yy491;
	}
yy491:
#line 96 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.num = integer(); return NonGroundGrammar::parser::token::NUMBER; }
#line 6134 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy492:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy492;
	default:	goto yy491;
	}
yy494:
	yych = *++YYCURSOR;
	switch (yych) {
	case '!':
	case '&':
	case '*':
	case '+':
	case '.':
	case '/':
	case ':':
	case ';':
	case '<':
	case '=':
	case '>':
	case '?':
	case '@':
	case '\\':
	case '^':
	case '|':
	case '~':	goto yy473;
	case '-':	goto yy532;
	default:	goto yy495;
	}
yy495:
#line 112 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::COLON; }
#line 6178 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy496:
	yych = *++YYCURSOR;
	switch (yych) {
	case '!':
	case '&':
	case '*':
	case '+':
	case '-':
	case '.':
	case '/':
	case ':':
	case ';':
	case '<':
	case '=':
	case '>':
	case '?':
	case '@':
	case '\\':
	case '^':
	case '|':
	case '~':	goto yy473;
	default:	goto yy497;
	}
yy497:
#line 109 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SEM; }
#line 6205 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy498:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy498;
	default:	goto yy500;
	}
yy500:
#line 97 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(string()); return NonGroundGrammar::parser::token::VARIABLE; }
#line 6280 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy501:
	++YYCURSOR;
#line 117 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::LBRACK; }
#line 6285 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy503:
	++YYCURSOR;
#line 118 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::RBRACK; }
#line 6290 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy505:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy506:
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy505;
	default:	goto yy507;
	}
yy507:
#line 95 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(string()); return NonGroundGrammar::parser::token::IDENTIFIER; }
#line 6366 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy508:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'o':	goto yy534;
	default:	goto yy506;
	}
yy509:
	++YYCURSOR;
#line 122 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::LBRACE; }
#line 6377 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy511:
	++YYCURSOR;
#line 123 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::RBRACE; }
#line 6382 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy513:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy514:
	switch (yych) {
	case '\n':	goto yy515;
	case '"':	goto yy516;
	case '\\':	goto yy518;
	default:	goto yy513;
	}
yy515:
	YYCURSOR = YYMARKER;
	if (yyaccept == 0) {
		goto yy467;
	} else {
		goto yy491;
	}
yy516:
	++YYCURSOR;
#line 98 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(unquote(string(1, 1)).c_str()); return NonGroundGrammar::parser::token::STRING; }
#line 6405 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy518:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '"':
	case '\\':
	case 'n':	goto yy513;
	default:	goto yy515;
	}
yy519:
	++YYCURSOR;
	YYSETCONDITION(yyccomment);
	continue;
yy521:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy522:
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy521;
	default:	goto yy478;
	}
yy523:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy535;
	default:	goto yy522;
	}
yy524:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'u':	goto yy536;
	default:	goto yy522;
	}
yy525:
	++YYCURSOR;
	YYSETCONDITION(yycblockcomment);
#line 156 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ bc++; continue; }
#line 6508 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy527:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\'':
	case '_':	goto yy527;
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':	goto yy498;
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy505;
	default:	goto yy515;
	}
yy529:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':	goto yy537;
	default:	goto yy515;
	}
yy530:
	yych = *++YYCURSOR;
	switch (yych) {
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy539;
	default:	goto yy515;
	}
yy531:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':	goto yy541;
	default:	goto yy515;
	}
yy532:
	yych = *++YYCURSOR;
	switch (yych) {
	case '!':
	case '&':
	case '*':
	case '+':
	case '-':
	case '.':
	case '/':
	case ':':
	case ';':
	case '<':
	case '=':
	case '>':
	case '?':
	case '@':
	case '\\':
	case '^':
	case '|':
	case '~':	goto yy473;
	default:	goto yy533;
	}
yy533:
#line 113 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::IF; }
#line 6642 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy534:
	yych = *++YYCURSOR;
	switch (yych) {
	case 't':	goto yy543;
	default:	goto yy506;
	}
yy535:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'f':	goto yy545;
	default:	goto yy522;
	}
yy536:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'p':	goto yy547;
	default:	goto yy522;
	}
yy537:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '0':
	case '1':	goto yy537;
	default:	goto yy491;
	}
yy539:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy539;
	default:	goto yy491;
	}
yy541:
	++YYCURSOR;
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':	goto yy541;
	default:	goto yy491;
	}
yy543:
	yych = *++YYCURSOR;
	switch (yych) {
	case '\'':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy505;
	default:	goto yy544;
	}
yy544:
#line 91 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ value.str = String::toRep(not_); return NonGroundGrammar::parser::token::NOT; }
#line 6785 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy545:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy521;
	case 'i':	goto yy549;
	default:	goto yy546;
	}
yy546:
#line 67 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::INFIMUM; }
#line 6857 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy547:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy521;
	case 'r':	goto yy550;
	default:	goto yy548;
	}
yy548:
#line 68 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ return NonGroundGrammar::parser::token::SUPREMUM; }
#line 6929 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy549:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy551;
	default:	goto yy522;
	}
yy550:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy552;
	default:	goto yy522;
	}
yy551:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'u':	goto yy553;
	default:	goto yy522;
	}
yy552:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy554;
	default:	goto yy522;
	}
yy553:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy555;
	default:	goto yy522;
	}
yy554:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'u':	goto yy556;
	default:	goto yy522;
	}
yy555:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy521;
	default:	goto yy546;
	}
yy556:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'm':	goto yy557;
	default:	goto yy522;
	}
yy557:
	yych = *++YYCURSOR;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'G':
	case 'H':
	case 'I':
	case 'J':
	case 'K':
	case 'L':
	case 'M':
	case 'N':
	case 'O':
	case 'P':
	case 'Q':
	case 'R':
	case 'S':
	case 'T':
	case 'U':
	case 'V':
	case 'W':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':
	case 'g':
	case 'h':
	case 'i':
	case 'j':
	case 'k':
	case 'l':
	case 'm':
	case 'n':
	case 'o':
	case 'p':
	case 'q':
	case 'r':
	case 's':
	case 't':
	case 'u':
	case 'v':
	case 'w':
	case 'x':
	case 'y':
	case 'z':	goto yy521;
	default:	goto yy548;
	}
/* *********************************** */
yyc_script_body:
	if ((YYLIMIT - YYCURSOR) < 5) YYFILL(5);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy562;
	case '\n':	goto yy563;
	case '#':	goto yy565;
	default:	goto yy560;
	}
yy560:
	++YYCURSOR;
yy561:
#line 183 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ continue; }
#line 7125 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy562:
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy566;
	case '#':	goto yy569;
	default:	goto yy561;
	}
yy563:
	++YYCURSOR;
#line 175 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{
            if(eof()) {
                lexerError(eof(loc), Potassco::toSpan("<EOF>", 5));
                return 0;
            }
            step();
            continue;
        }
#line 7146 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy565:
	yych = *(YYMARKER = ++YYCURSOR);
	switch (yych) {
	case 'e':	goto yy570;
	default:	goto yy561;
	}
yy566:
	++YYCURSOR;
	if ((YYLIMIT - YYCURSOR) < 4) YYFILL(4);
	yych = *YYCURSOR;
	switch (yych) {
	case '\t':
	case '\r':
	case ' ':	goto yy566;
	case '#':	goto yy569;
	default:	goto yy568;
	}
yy568:
	YYCURSOR = YYMARKER;
	goto yy561;
yy569:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'e':	goto yy570;
	default:	goto yy568;
	}
yy570:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'n':	goto yy571;
	default:	goto yy568;
	}
yy571:
	yych = *++YYCURSOR;
	switch (yych) {
	case 'd':	goto yy572;
	default:	goto yy568;
	}
yy572:
	++YYCURSOR;
	YYSETCONDITION(yycnormal);
#line 162 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{
            auto span = string();
            size_t size = span.size - 4;
            for (; size > 0; --size) {
                char c = span[size - 1];
                if (c != ' ' && c != '\t' && c != '\r') {
                    break;
                }
            }
            std::string s(span.first, span.first + size);
            value.str = String::toRep(s.c_str());
            return NonGroundGrammar::parser::token::CODE;
        }
#line 7202 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
/* *********************************** */
yyc_blockcomment:
	if ((YYLIMIT - YYCURSOR) < 2) YYFILL(2);
	yych = *YYCURSOR;
	switch (yych) {
	case '\n':	goto yy578;
	case '%':	goto yy580;
	case '*':	goto yy582;
	default:	goto yy576;
	}
yy576:
	++YYCURSOR;
yy577:
#line 189 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ continue; }
#line 7218 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy578:
	++YYCURSOR;
#line 188 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ if(eof()) { lexerError(eof(loc), Potassco::toSpan("<EOF>", 5)); return 0; } step(); continue; }
#line 7223 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy580:
	yych = *++YYCURSOR;
	switch (yych) {
	case '*':	goto yy583;
	default:	goto yy581;
	}
yy581:
	YYSETCONDITION(yyccomment);
	continue;
yy582:
	yych = *++YYCURSOR;
	switch (yych) {
	case '%':	goto yy585;
	default:	goto yy577;
	}
yy583:
	++YYCURSOR;
#line 186 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ bc++; continue; }
#line 7243 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy585:
	++YYCURSOR;
#line 185 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ if(--bc == 0) { condition(yycnormal); start(loc); } continue; }
#line 7248 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
/* *********************************** */
yyc_comment:
	if (YYLIMIT <= YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	switch (yych) {
	case '\n':	goto yy591;
	default:	goto yy589;
	}
yy589:
	++YYCURSOR;
#line 204 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{ continue; }
#line 7261 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
yy591:
	++YYCURSOR;
#line 191 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"
	{
            if(eof()) {
                if(bc > 0) { lexerError(eof(loc), Potassco::toSpan("<EOF>", 5)); }
                return 0;
            }
            step();
            if (bc > 0) { condition(yycblockcomment); }
            else {
                condition(yycnormal);
                start(loc);
            }
            continue;
        }
#line 7278 "/home/runner/work/clingo/clingo/build/libgringo//src/input/nongroundlexer.hh"
}
#line 205 "/home/runner/work/clingo/clingo/libgringo//src/input/nongroundlexer.xch"

    }
    assert(false);
    return 0;
}

#undef YYCTYPE
#undef YYCURSOR
#undef YYLIMIT
#undef YYMARKER
#undef YYFILL
#undef YYCTXMARKER
#undef YYGETCONDITION
#undef YYSETCONDITION
